======
Corpus
======

.. figure:: icons/corpus.png

Load a corpus of text documents, (optionally) tagged with categories.

Signals
-------

**Inputs**:

-  (None)

**Outputs**:

-  **Corpus**

Corpus instance.

Description
-----------

**Corpus** widget reads text corpora from
files and sends a corpus instance to its output channel.
History of the most recently opened files is maintained in the widget.
The widget also includes a directory with sample corpora that come
pre-installed with the add-on.

Example
-------

No example yet for this widget.
